# speclike

**speclike** is a partial support library for writing structured and spec-like tests using Python.

This project aims to make test code read more like specifications, inspired by ideas from contract testing and design-by-contract.
It currently provides lightweight markers (`setup`, `before`, `after`, `invariant`) and a pytest-based test dispatcher.

---

## Status

This project is in **very early development (alpha stage)**.  
APIs and behavior may change without notice.

---

## License

MIT License © 2025 minoru_jp